import {
  Client,
  Account,
  AppwriteException,
  Avatars,
  Databases,
  Functions,
  Graphql,
  ID,
  Locale,
  Permission,
  Query,
  Role,
  Storage,
  Teams,
  Messaging
} from "appwrite";
import { defineNuxtPlugin } from "#imports";
export default defineNuxtPlugin((nuxtApp) => {
  const moduleOptions = nuxtApp.$config.public.appwrite;
  const config = {
    endpoint: moduleOptions.endpoint || "https://cloud.appwrite.io/v1",
    project: moduleOptions.project
  };
  const client = new Client();
  client.setEndpoint(config.endpoint);
  client.setProject(config.project);
  return {
    provide: {
      appwrite: {
        config,
        client,
        account: new Account(client),
        avatars: new Avatars(client),
        database: new Databases(client),
        functions: new Functions(client),
        graphql: new Graphql(client),
        locale: new Locale(client),
        storage: new Storage(client),
        teams: new Teams(client),
        messaging: new Messaging(client),
        Permission,
        Query,
        Role,
        AppwriteException,
        ID
      }
    }
  };
});
